@@ -1,7 +1,7 @@
 // -*- c-basic-offset: 2 -*-
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2009 Licq developers
+ * Copyright (C) 2007-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,14 +31,26 @@ class ProtoComboBox : public QComboBox
   Q_OBJECT
 
 public:
-  ProtoComboBox(QWidget* parent = 0);
-  ProtoComboBox(bool skipExisting, QWidget* parent = 0);
+  enum Filter
+  {
+    FilterIncludeAll,
+    FilterOwnersOnly,
+    FilterSkipOwners,
+  };
+
+  /**
+   * Constructor
+   *
+   * @param filter Which protocols to include
+   * @param parent Parent widget
+   */
+  ProtoComboBox(unsigned filter = FilterIncludeAll, QWidget* parent = 0);
 
   unsigned long currentPpid() const;
   bool setCurrentPpid(unsigned long ppid);
 
 private:
-  void fillComboBox(bool skipExisting = false);
+  void fillComboBox(unsigned filter);
 };
 
 } // namespace LicqQtGui
